@@ -21,7 +21,7 @@ function(x, components = FALSE)
                    if(length(args) != a)
                        stop("Wrong number of arguments.")
                    t <- .split_into_components(do.call("cbind", args))
-                   ind <- rbind(mapply(sets:::.exact_match, t, D))
+                   ind <- rbind(mapply(.exact_match, t, D))
                    if (any(is.na(ind)))
                        stop("Out-of-domain elements.")
                    as.logical(I[ind])
@@ -29,7 +29,7 @@ function(x, components = FALSE)
            else
                function(t) {
                    t <- .split_into_components(t)
-                   ind <- rbind(mapply(sets:::.exact_match, t, D))
+                   ind <- rbind(mapply(.exact_match, t, D))
                    if (any(is.na(ind)))
                        stop("Out-of-domain elements.")
                    as.logical(I[ind])
